@@ -19,11 +19,11 @@
 
 import os, sys
 
-tablesdir = "/opt/gnome//share/liblouis/tables"
+tablesdir = "/usr/share/liblouis/tables"
 
-gtkbuilder_dir = os.path.join("/opt/gnome", 'share', 'dots')
+gtkbuilder_dir = os.path.join("/home/fer/dist-dots", 'share', 'dots')
 
-LOCALE_DIR = os.path.join("/opt/gnome", 'share', 'locale')
+LOCALE_DIR = os.path.join("/home/fer/dist-dots", 'share', 'locale')
 DOMAIN = 'dots'
 
 
